@@ -7,10 +7,11 @@
 #' @details WKT strings longer than 10000 characters will not be
 #' accepted by the ALA- so the sf object or WKT string may need to be
 #' simplified.
-#' @return WKT string representing the area provided.
+#' @return length-1 object of class \code{character} and \code{ala_locations},
+#' containing a WKT string representing the area provided.
 #' @seealso \code{\link{select_taxa}}, \code{\link{select_filters}} and
-#' \code{\link{select_columns}} for other ways to restrict the information returned
-#' by \code{\link{ala_occurrences}} and related functions.
+#' \code{\link{select_columns}} for other ways to restrict the information
+#' returned by \code{\link{ala_occurrences}} and related functions.
 #' @examples \dontrun{
 #' # Search for records using a shapefile
 #' locations <- select_locations(st_read(path/to/shapefile))
@@ -21,14 +22,13 @@
 #' -29.39064,142.36228 -29.39064,142.36228 -29.00703))"
 #' ala_occurrences(locations = select_locations(wkt))
 #' }
-#' @export select_locations
-
+#' @export
 select_locations <- function(query) {
   # currently a bug where the ALA doesn't accept some polygons
   # to avoid any issues, any polygons should be converted to multipolygons
   
   if ("sf" %in% class(query) || "sfc" %in% class(query)) {
-    return(build_wkt(query))
+    out_query <- build_wkt(query)
   } else {
     validate_wkt(query)
     if (str_detect(query, "POLYGON") & ! str_detect(query, "MULTIPOLYGON")) {
@@ -37,8 +37,10 @@ select_locations <- function(query) {
       # add an extra bracket
       query <- paste0(query, ")")
     }
-    return(query)
+    out_query <- query
   }
+  class(out_query) <- append(class(out_query), "ala_locations")
+  out_query
 
 }
 
@@ -74,4 +76,4 @@ validate_wkt <- function(wkt) {
       }
     }
   }
-}
\ No newline at end of file
+}
