@@ -2,17 +2,15 @@ context("Test select_locations")
 
 test_that("select_locations checks inputs", {
   skip_on_cran()
-  poly_path <- "../test_data/act_state_polygon_shp/ACT_STATE_POLYGON_shp.shp"
+  poly_path <- "../testdata/act_state_polygon_shp/ACT_STATE_POLYGON_shp.shp"
   expect_error(
     select_locations(st_read(poly_path),
                  readLines("../testdata/short_act_wkt.txt")))
   expect_error(select_locations(st_read(poly_path)))
-  
   expect_error(select_locations(readLines("../testdata/long_act_wkt.txt")))
 })
 
 test_that("select_locations finds polygon errors", {
-  skip_on_cran()
   invalid_wkt <- "POLYGON((145.71622941565508 -32.17848852726597,))"
   expect_warning(select_locations(invalid_wkt))
 
@@ -21,7 +19,11 @@ test_that("select_locations finds polygon errors", {
 })
 
 test_that("select_locations converts to multipolygon", {
-  skip_on_cran()
   wkt <- "POLYGON((143.32 -18.78,145.30 -20.52,141.52 -21.50,143.32 -18.78))"
   expect_match(select_locations(wkt), "MULTIPOLYGON")
-})
\ No newline at end of file
+})
+
+test_that("select_locations converts sf object to multipolygon", {
+  wkt <- "POLYGON((143.32 -18.78,145.30 -20.52,141.52 -21.50,143.32 -18.78))"
+  expect_match(build_wkt(st_as_sfc(wkt)), "MULTIPOLYGON")
+})
