@@ -1,16 +1,17 @@
 context("Test helper functions")
 
-test_that("Multiple negated queries are joined with 'AND'", {
-  skip_on_cran()
-  expect_match(build_taxa_query(c("id1", "id2"), FALSE), "AND")
+test_that("Negated queries have a minus sign", {
   expect_match(query_term(name = "test", value = c("a", "b"), include = FALSE),
-               "AND")
+               "-")
 })
 
 test_that("Taxa arguments are checked", {
-  skip_on_cran()
-  ala_config(verbose = FALSE)
+  galah_config(verbose = FALSE)
   expect_error(check_taxa_arg("Vulpes vulpes"))
-  expect_silent("1234")
+  expect_silent(check_taxa_arg("1234"))
+  
+})
+
+vcr::use_cassette("select_taxa", {
   expect_silent(check_taxa_arg(select_taxa("Vulpes vulpes")))
 })
\ No newline at end of file
